
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2025 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef RG_RESCALECOMMAND_H
#define RG_RESCALECOMMAND_H

#include "document/BasicCommand.h"
#include "base/TimeT.h"

#include <QCoreApplication>
#include <QString>


namespace Rosegarden
{


class EventSelection;


class RescaleCommand : public BasicCommand
{
    Q_DECLARE_TR_FUNCTIONS(Rosegarden::RescaleCommand)

public:
    RescaleCommand(EventSelection &selection,
                   timeT newDuration,
                   bool closeGap);

    static QString getGlobalName() { return tr("Stretch or S&quash..."); }

protected:
    void modifySegment() override;

private:
    timeT rescale(timeT) const;
    static timeT getAffectedEndTime(EventSelection &selection,
                                    timeT newDuration,
                                    bool closeGap);

    EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
    timeT m_oldDuration;
    timeT m_newDuration;
    bool m_closeGap;
};



}

#endif
